@@ -11,19 +11,20 @@ Refactored API with:
 from __future__ import annotations
 
 import asyncio
-from contextlib import asynccontextmanager
+from contextlib import asynccontextmanager, suppress
 from datetime import datetime
 import logging
 import time
 from typing import Any
+import json
 
 from evenage import __version__ as pkg_version
 from evenage.core import (
     AgentRunner,
     BackendFactory,
+    EvenAgeConfig,
     run_agent,
 )
-from evenage.core.config import load_runtime_config, EvenAgeConfig
 from fastapi import FastAPI, HTTPException, WebSocket, WebSocketDisconnect
 from fastapi.middleware.cors import CORSMiddleware
 from pydantic import BaseModel
@@ -46,6 +47,12 @@ class SubmitPromptRequest(BaseModel):
     inputs: dict[str, Any]
 
 
+class CancelPromptResponse(BaseModel):
+    ok: bool
+    prompt_id: str
+    status: str
+
+
 class ReplayJobRequest(BaseModel):
     """Request to replay a job."""
     reexecute: bool = False
@@ -80,8 +87,8 @@ async def lifespan(app: FastAPI):
     """Initialize and cleanup services."""
     global config, factory, database, message_bus
 
-    # Load configuration (prefer project .evenage/config.json)
-    config = load_runtime_config()
+    # Load configuration
+    config = EvenAgeConfig()
     factory = BackendFactory(config)
 
     # Initialize services
@@ -299,43 +306,49 @@ async def replay_job(job_id: str, request: ReplayJobRequest):
 @app.post("/api/prompts")
 async def submit_prompt(request: SubmitPromptRequest):
     """
-    Submit a new prompt execution.
+    Submit a new prompt execution (non-blocking).
 
-    Creates prompt execution, runs agent, stores results and traces.
-
-    Args:
-        request: Prompt submission request
-
-    Returns:
-        Prompt result with prompt_id, status, result/error
+    - Creates a prompt record immediately
+    - Kicks off background agent execution using the same prompt_id as job_id
+    - Returns promptly with status 'running' and the prompt_id
     """
     try:
-        result = await run_agent(
-            agent_name=request.prompt_name,
-            inputs=request.inputs,
-            env_config=config
-        )
+        # Create prompt record first and mark as running
+        prompt_id = database.create_prompt(None, request.prompt_name, request.inputs)
+        database.update_prompt_status(prompt_id, "running")
 
-        # Store using new prompt terminology
-        prompt_id = result.get("job_id")  # run_agent still returns job_id
-        database.create_prompt(prompt_id, request.prompt_name, request.inputs)
+        async def _run_in_background(pid: str):
+            try:
+                runner = AgentRunner(env_config=config)
+                result = await runner.run(
+                    inputs=request.inputs,
+                    agent_name=request.prompt_name,
+                    job_id=pid,
+                )
 
-        if result.get("status") == "success":
-            database.save_prompt_result(prompt_id, result.get("result", {}), status="completed")
-        else:
-            database.save_prompt_result(
-                prompt_id,
-                {"error": result.get("error")},
-                status="failed"
-            )
+                # Map status to prompt status
+                status = result.get("status", "failed")
+                outputs = result.get("result") or {}
+                error = result.get("error")
+
+                # Prefer explicit outputs; if only error present, store that
+                if error and not outputs:
+                    outputs = {"error": error}
+
+                # Normalize success to 'completed'
+                prompt_status = "completed" if status == "success" else status
+                database.save_prompt_result(pid, outputs, status=prompt_status)
+            except Exception as e:
+                logger.exception("Background prompt run failed")
+                database.save_prompt_result(pid, {"error": str(e)}, status="failed")
+
+        # Fire-and-forget background task
+        asyncio.create_task(_run_in_background(prompt_id))
 
         return {
             "prompt_id": prompt_id,
-            "status": result["status"],
-            "result": result.get("result"),
-            "error": result.get("error"),
-            "duration_ms": result.get("duration_ms"),
-            "agent": result.get("agent")
+            "status": "running",
+            "agent": request.prompt_name
         }
 
     except Exception as e:
@@ -464,9 +477,10 @@ async def chat_with_agent(agent_name: str, request: AgentChatRequest):
 
         if request.wait:
             # Wait for response
+            # Message bus expects positional timeout in seconds (timeout_sec)
             response = await message_bus.wait_for_response(
                 task_id,
-                timeout=request.timeout
+                request.timeout
             )
 
             if response:
@@ -491,6 +505,96 @@ async def chat_with_agent(agent_name: str, request: AgentChatRequest):
         raise HTTPException(status_code=500, detail=str(e))
 
 
+@app.get("/api/responses/{task_id}/resolved")
+async def get_resolved_response(task_id: str):
+    """
+    Resolve and return a task response. If the response was offloaded to storage,
+    this endpoint fetches the full payload from MinIO/S3 and returns it.
+
+    Args:
+        task_id: Task identifier as returned by delegation/chat APIs
+
+    Returns:
+        JSON object containing either the inline response or the resolved payload
+        when the response was offloaded. Shape:
+        {
+          "task_id": str,
+          "offloaded": bool,
+          "pointer": {"bucket": str, "key": str, "size_bytes": int} | None,
+          "data": Any  # full response payload
+        }
+    """
+    try:
+        # Try to read existing response without blocking
+        response: dict | None = None
+
+        # MemoryBus fast-path
+        if hasattr(message_bus, "_responses"):
+            try:
+                response = getattr(message_bus, "_responses", {}).get(task_id)
+            except Exception:
+                response = None
+
+        # RedisBus path: read key directly to avoid pub/sub
+        if response is None and hasattr(message_bus, "_get_client"):
+            try:
+                client = await message_bus._get_client()  # type: ignore[attr-defined]
+                raw = await client.get(f"evenage:response:{task_id}")
+                if raw:
+                    response = json.loads(raw)
+            except Exception:
+                response = None
+
+        # Fallback minimal wait
+        if response is None:
+            with suppress(Exception):
+                response = await message_bus.wait_for_response(task_id, 1)
+
+        if not response:
+            raise HTTPException(status_code=404, detail="Response not found or expired")
+
+        # If it's a pointer to offloaded content, fetch and return full data
+        if isinstance(response, dict) and response.get("offloaded") and response.get("bucket") and response.get("key"):
+            bucket = response.get("bucket")
+            key = response.get("key")
+
+            storage = factory.create_storage_backend()
+            try:
+                blob = await storage.get_object(bucket, key)
+                try:
+                    data = json.loads(blob.decode("utf-8"))
+                except Exception:
+                    # Return raw text if not valid JSON
+                    data = blob.decode("utf-8", errors="replace")
+            except Exception as e:
+                raise HTTPException(status_code=502, detail=f"Failed to fetch offloaded artifact: {e}")
+
+            return {
+                "task_id": task_id,
+                "offloaded": True,
+                "pointer": {
+                    "bucket": bucket,
+                    "key": key,
+                    "size_bytes": response.get("size_bytes")
+                },
+                "data": data
+            }
+
+        # Inline payload already present
+        return {
+            "task_id": task_id,
+            "offloaded": False,
+            "pointer": None,
+            "data": response
+        }
+
+    except HTTPException:
+        raise
+    except Exception as e:
+        logger.exception("Failed to resolve response")
+        raise HTTPException(status_code=500, detail=str(e))
+
+
 @app.get("/api/traces")
 async def list_traces(
     job_id: str | None = None,
@@ -511,6 +615,57 @@ async def list_traces(
         raise HTTPException(status_code=500, detail=str(e))
 
 
+@app.get("/api/traces/grouped")
+async def get_grouped_traces(limit: int = 50):
+    """
+    Get traces grouped by job_id.
+    
+    Returns traces organized by job_id, showing complete multi-agent runs together.
+    Each group contains all traces (coordinator, researcher, etc.) for that job.
+    """
+    try:
+        # Get recent traces with job_id
+        all_traces = database.list_traces(limit=limit * 10)  # Get more to ensure we have enough jobs
+        
+        # Group traces by job_id
+        grouped: dict[str, list] = {}
+        for trace in all_traces:
+            job_id = trace.get('job_id')
+            if job_id:
+                if job_id not in grouped:
+                    grouped[job_id] = []
+                grouped[job_id].append(trace)
+        
+        # Convert to list format with metadata
+        result = []
+        for job_id, traces in list(grouped.items())[:limit]:
+            # Sort traces by timestamp
+            traces.sort(key=lambda t: t.get('timestamp', ''))
+            
+            # Extract metadata
+            agents = list(set(t.get('agent_name') for t in traces if t.get('agent_name')))
+            start_time = traces[0].get('timestamp') if traces else None
+            end_time = traces[-1].get('timestamp') if traces else None
+            
+            result.append({
+                'job_id': job_id,
+                'trace_count': len(traces),
+                'agents': agents,
+                'start_time': start_time,
+                'end_time': end_time,
+                'traces': traces
+            })
+        
+        # Sort by most recent first
+        result.sort(key=lambda g: g.get('start_time', ''), reverse=True)
+        
+        return {'grouped_traces': result}
+        
+    except Exception as e:
+        logger.exception("Failed to get grouped traces")
+        raise HTTPException(status_code=500, detail=str(e))
+
+
 @app.get("/api/traces/{trace_id}")
 async def get_trace(trace_id: str):
     """Get a single trace by id with full payload."""
@@ -631,6 +786,93 @@ async def websocket_events(websocket: WebSocket):
         logger.error(f"WebSocket error: {e}")
 
 
+@app.websocket("/ws/prompts/{prompt_id}")
+async def websocket_prompt_traces(websocket: WebSocket, prompt_id: str):
+    """
+    WebSocket endpoint for live trace streaming for a specific prompt execution.
+    
+    Clients connect when starting a prompt and receive real-time traces
+    as they are generated during execution.
+    """
+    await websocket.accept()
+    logger.info(f"WebSocket connected for prompt {prompt_id}")
+    
+    # Track last seen trace ID to avoid duplicates
+    last_trace_id = 0
+    
+    try:
+        while True:
+            # Get traces for this prompt/job
+            traces = database.get_job_traces(prompt_id)
+            
+            # Filter to only new traces
+            new_traces = [t for t in traces if t.get('id', 0) > last_trace_id]
+            
+            if new_traces:
+                # Update last seen
+                last_trace_id = max(t.get('id', 0) for t in new_traces)
+                
+                # Send new traces
+                for trace in new_traces:
+                    await websocket.send_json({
+                        "type": "trace",
+                        "data": trace
+                    })
+            
+            # Check if prompt is complete
+            prompt_result = database.get_prompt_result(prompt_id)
+            if prompt_result and prompt_result.get('status') in ['completed', 'failed', 'error', 'canceled']:
+                # Send completion event
+                await websocket.send_json({
+                    "type": "complete",
+                    "data": {
+                        "status": prompt_result.get('status'),
+                        "outputs": prompt_result.get('outputs'),
+                        "error": prompt_result.get('error')
+                    }
+                })
+                logger.info(f"Prompt {prompt_id} completed, closing WebSocket")
+                break
+            
+            # Poll interval
+            await asyncio.sleep(0.3)
+    
+    except WebSocketDisconnect:
+        logger.info(f"WebSocket client disconnected for prompt {prompt_id}")
+    except Exception as e:
+        logger.error(f"WebSocket error for prompt {prompt_id}: {e}")
+        try:
+            await websocket.send_json({
+                "type": "error",
+                "data": {"error": str(e)}
+            })
+        except:
+            pass
+
+
+    @app.post("/api/prompts/{prompt_id}/cancel", response_model=CancelPromptResponse)
+    async def cancel_prompt(prompt_id: str):
+        """Request cancellation of a running prompt. This sets a cancel flag and updates status."""
+        try:
+            # Signal cancel to runtime via message bus
+            with suppress(Exception):
+                # message_bus may not implement cancel in all backends; best-effort
+                await message_bus.cancel_job(prompt_id)
+
+            # Update prompt status to canceled
+            database.update_prompt_status(prompt_id, "canceled")
+            # Trace cancel request
+            try:
+                database.append_trace(prompt_id, "api", "task_cancel_requested", {"by": "user"})
+            except Exception:
+                pass
+
+            return CancelPromptResponse(ok=True, prompt_id=prompt_id, status="canceled")
+        except Exception as e:
+            logger.exception("Failed to cancel prompt")
+            raise HTTPException(status_code=500, detail=str(e))
+
+
 if __name__ == "__main__":
     import uvicorn
     uvicorn.run(app, host="0.0.0.0", port=8000)
