@@ -87,26 +87,6 @@ def init(project_name: str | None, path: str):
         f"Creating project: [bold]{project_path.name}[/bold]",
     )
 
-    # Interactive infra choices
-    click.echo("")
-    enable_scaling = click.confirm("Do you want to scale your application for large workloads?", default=True)
-    queue_choice = "inmemory"
-    db_choice = "local"
-    storage_choice = "local"
-    if enable_scaling:
-        if click.confirm("Do you want to use a queueing system for distributed tasks? (Redis)", default=True):
-            queue_choice = "redis"
-        else:
-            queue_choice = "inmemory"
-        if click.confirm("Do you want to store traces and agent states in a database? (PostgreSQL)", default=True):
-            db_choice = "postgres"
-        else:
-            db_choice = "local"  # will map to sqlite
-        if click.confirm("Do you want to store large files or artifacts (MinIO)", default=True):
-            storage_choice = "minio"
-        else:
-            storage_choice = "local"
-
     with Progress(
         SpinnerColumn(),
         TextColumn("[progress.description]{task.description}"),
@@ -122,7 +102,7 @@ def init(project_name: str | None, path: str):
 
         # Generate configuration files
         progress.update(task, description="Creating configuration...")
-        _generate_config_files(project_path, project_path.name, enable_scaling, queue_choice, db_choice, storage_choice)
+        _generate_config_files(project_path, project_path.name)
 
         # Generate Docker setup
         progress.update(task, description="Creating Docker configuration...")
@@ -149,8 +129,8 @@ def _create_directories(project_path: Path) -> None:
     directories = [
         project_path,
         project_path / "agents",
+        project_path / "tools",
         project_path / "workers",
-        project_path / "pipelines",
     ]
 
     for directory in directories:
@@ -169,11 +149,11 @@ def _generate_core_modules(project_path: Path) -> None:
     """
 
 
-def _generate_config_files(project_path: Path, project_name: str, enable_scaling: bool, queue_choice: str, db_choice: str, storage_choice: str) -> None:
+def _generate_config_files(project_path: Path, project_name: str) -> None:
     """Generate configuration files."""
     renderer = get_template_renderer()
 
-    # evenage.yml (legacy project config for scaffolding)
+    # evenage.yml
     config = ProjectConfigSchema(
         project=ProjectDetails(
             name=project_name,
@@ -190,18 +170,6 @@ def _generate_config_files(project_path: Path, project_name: str, enable_scaling
     # .env
     renderer.render_to_file("dotenv.j2", project_path / ".env", {})
 
-    # .evenage/config.json (runtime backend config)
-    from json import dumps
-    runtime_cfg = {
-        "enable_scaling": bool(enable_scaling),
-        "queue_backend": queue_choice if enable_scaling else "inmemory",
-        "db_backend": db_choice if enable_scaling else "local",
-        "storage_backend": storage_choice if enable_scaling else "local",
-    }
-    cfg_dir = project_path / ".evenage"
-    cfg_dir.mkdir(parents=True, exist_ok=True)
-    (cfg_dir / "config.json").write_text(dumps(runtime_cfg, indent=2), encoding="utf-8")
-
 
 def _generate_docker_setup(project_path: Path) -> None:
     """Generate Docker configuration."""
@@ -219,25 +187,23 @@ def _generate_default_agent(project_path: Path) -> None:
     # Create agents directory __init__
     write_file(project_path / "agents" / "__init__.py", "")
 
-    # Define both default agents
+    # Define both default agents (flat files in agents/)
     default_agents = [
         {
             "name": "coordinator",
-            "role": "Coordinator Agent",
-            "goal": "Orchestrate multi-agent workflows and delegate tasks to specialist agents.",
-            "backstory": "An experienced coordinator that analyzes tasks, delegates to specialists, and synthesizes results.",
-            "template": "agent_coordinator.py.j2",
-            "tools": [],
-            "allow_delegation": True,
+            "role": "Orchestrator & Task Planner",
+            "goal": "Break down complex tasks into subtasks and coordinate their execution across specialized agents",
+            "backstory": "Experienced project manager with a talent for decomposition and delegation.",
+            "is_coordinator": True,
+            "available_agents": ["researcher", "analyst", "writer"],
         },
         {
             "name": "researcher",
             "role": "Research Agent",
             "goal": "Research topics on the web and summarize findings concisely.",
             "backstory": "A helpful researcher that gathers and condenses information from reliable web sources.",
-            "template": "agent_handler.py.j2",
-            "tools": ["web_search"],
-            "allow_delegation": False,
+            "is_coordinator": False,
+            "available_agents": [],
         }
     ]
 
@@ -247,67 +213,49 @@ def _generate_default_agent(project_path: Path) -> None:
         agent_name = agent_config["name"]
         agent_names.append(agent_name)
 
-        # Agent directory structure
-        agent_path = project_path / "agents" / agent_name
-        agent_path.mkdir(parents=True, exist_ok=True)
-        write_file(agent_path / "__init__.py", "")
+        # agents/__init__.py once
+        write_file(project_path / "agents" / "__init__.py", "")
 
-        # Create tools directory if agent has tools
-        if agent_config["tools"]:
-            tools_path = agent_path / "tools"
-            tools_path.mkdir(parents=True, exist_ok=True)
-            write_file(tools_path / "__init__.py", "")
-
-            # Generate web search tool for researcher
-            if "web_search" in agent_config["tools"]:
-                renderer.render_to_file("tool_web_search.py.j2", tools_path / "web_search.py", {})
-
-        # Agent handler (use coordinator template for coordinator, standard handler for others)
-        handler_context = {
-            "agent_name": agent_name,
+        # Render flat agent file
+        agent_context = {
+            "name": agent_name,
             "role": agent_config["role"],
             "goal": agent_config["goal"],
             "backstory": agent_config["backstory"],
-            "allow_delegation": agent_config["allow_delegation"],
-            "max_iterations": 15,
-            "description": f"Default {agent_name} agent.",
-            "tools": agent_config["tools"],
+            "is_coordinator": agent_config.get("is_coordinator", False),
+            "available_agents": agent_config.get("available_agents", []),
+            "model_env": f"{agent_name.upper()}_MODEL",
+            "model": "gemini-2.5-flash",
+            "fallback_model_env": f"{agent_name.upper()}_FALLBACK_MODEL",
+            "fallback_model": "gpt-3.5-turbo",
+            "temperature": 0.3 if agent_config.get("is_coordinator") else 0.2,
+            "max_retries": 3,
+            "timeout": 600,
+            "instructions": (
+                "When you receive a task: 1) Analyze 2) Plan 3) Execute using tools 4) Synthesize results."
+                if agent_config.get("is_coordinator")
+                else "Be concise and cite sources when researching."
+            ),
         }
-        renderer.render_to_file(agent_config["template"], agent_path / "handler.py", handler_context)
+        renderer.render_to_file("agent_flat.py.j2", project_path / "agents" / f"{agent_name}.py", agent_context)
 
-        # Agent prompt policy (user-visible system prompt supplement)
+        # Worker scripts
         renderer.render_to_file(
-            "prompt.md.j2",
-            agent_path / "prompt.md",
-            {
-                "agent_name": agent_name,
-                "role": agent_config["role"],
-                "goal": agent_config["goal"],
-                "backstory": agent_config["backstory"],
-            },
-        )
-
-        # Worker
-        worker_context = {
-            "agent_name": agent_name,
-            "role": agent_config["role"],
-            "goal": agent_config["goal"],
-        }
-        renderer.render_to_file(
-            "agent_worker.py.j2",
+            "worker_runner.py.j2",
             project_path / "workers" / f"{agent_name}_worker.py",
-            worker_context,
+            {"agent_name": agent_name},
         )
 
-        # Add worker service to docker-compose.yml
+        # Add worker to docker-compose
         add_worker_to_compose(project_path, agent_name)
 
-    # Main entrypoint - routes to coordinator by default
-    renderer.render_to_file(
-        "main_agent_entry.py.j2",
-        project_path / "main.py",
-        {"default_agent": "coordinator"},
-    )
+    # Tools package and defaults
+    write_file(project_path / "tools" / "__init__.py", "")
+    renderer.render_to_file("tools_web.py.j2", project_path / "tools" / "web_tools.py", {})
+    renderer.render_to_file("tools_communication.py.j2", project_path / "tools" / "communication_tools.py", {})
+
+    # Main entry - simple runner selecting agent by env
+    renderer.render_to_file("main_flat.py.j2", project_path / "main.py", {})
 
     # Update evenage.yml to add both agents
     config_path = project_path / "evenage.yml"
@@ -319,17 +267,6 @@ def _generate_default_agent(project_path: Path) -> None:
     with open(config_path, "w", encoding="utf-8") as f:
         yaml.dump(config_data, f, default_flow_style=False, sort_keys=False)
 
-    # Create example pipeline
-    pipeline_context = {
-        "pipeline_name": "research_pipeline",
-        "description": "Example research pipeline using the researcher agent",
-    }
-    renderer.render_to_file(
-        "pipeline.yml.j2",
-        project_path / "pipelines" / "research_pipeline.yml",
-        pipeline_context,
-    )
-
 
 def _generate_readme(project_path: Path, project_name: str) -> None:
     """Generate project README."""
