@@ -113,11 +113,10 @@ def run_pipeline(pipeline_file: str):
     # Use EvenAge runtime (shared env for all agents)
     import asyncio
 
-    from evenage.core import AgentRunner  # type: ignore
-    from evenage.core.config import load_runtime_config
+    from evenage.core import AgentRunner, EvenAgeConfig  # type: ignore
 
     results: dict[str, Any] = {}
-    runner = AgentRunner(env_config=load_runtime_config())
+    runner = AgentRunner(env_config=EvenAgeConfig())
     for stage in stages:
         agent_name = stage.get("agent")
         # Support both {inputs: {...}} and arbitrary keys; if tasks format, pass remaining keys except 'agent'
@@ -137,6 +136,25 @@ def run_pipeline(pipeline_file: str):
 def run_agent_cmd(agent_name: str, inputs_json: str):
     """Run a single agent locally using AgentRunner."""
     import asyncio
+    import os
+    import sys
+
+    # Ensure local project imports work (agents package)
+    try:
+        cwd = str(Path.cwd())
+        if cwd not in sys.path:
+            sys.path.insert(0, cwd)
+    except Exception:
+        pass
+
+    # Favor local-friendly defaults to avoid external deps
+    try:
+        if not os.environ.get("DATABASE_URL"):
+            os.environ["DATABASE_URL"] = "sqlite:///evenage.db"
+        if not os.environ.get("QUEUE_BACKEND") and not os.environ.get("REDIS_URL"):
+            os.environ["QUEUE_BACKEND"] = "memory"
+    except Exception:
+        pass
 
     if not validate_project_directory(Path.cwd()):
         raise ProjectNotFoundError()
@@ -148,13 +166,12 @@ def run_agent_cmd(agent_name: str, inputs_json: str):
 
     # Use new runtime
     try:
-        from evenage.core import run_agent
-        from evenage.core.config import load_runtime_config
+        from evenage.core import EvenAgeConfig, run_agent
 
         print_panel("Running agent", f"agent: {agent_name}")
 
         # Load environment config
-        config = load_runtime_config()
+        config = EvenAgeConfig()
 
         # Run agent
         result = asyncio.run(run_agent(agent_name, inputs, config))
@@ -182,13 +199,12 @@ def replay_job(job_id: str, reexecute: bool):
         raise ProjectNotFoundError()
 
     try:
-        from evenage.core import AgentRunner
-        from evenage.core.config import load_runtime_config
+        from evenage.core import AgentRunner, EvenAgeConfig
 
         print_panel("Replaying job", f"job_id: {job_id}\nreexecute: {reexecute}")
 
         # Load environment config
-        config = load_runtime_config()
+        config = EvenAgeConfig()
         runner = AgentRunner(env_config=config)
 
         # Replay
