@@ -61,6 +61,23 @@ def run_local(agent: str, input_json: str):
     """Run an agent once locally using in-memory components (no Redis/DB)."""
     import json
     import asyncio
+    import os
+    import sys
+    # Ensure current working directory is importable (for 'agents' package)
+    try:
+        cwd = os.getcwd()
+        if cwd not in sys.path:
+            sys.path.insert(0, cwd)
+    except Exception:
+        pass
+    # Sensible local defaults to avoid external deps
+    try:
+        if not os.environ.get("DATABASE_URL"):
+            os.environ["DATABASE_URL"] = "sqlite:///evenage.db"
+        if not os.environ.get("QUEUE_BACKEND") and not os.environ.get("REDIS_URL"):
+            os.environ["QUEUE_BACKEND"] = "memory"
+    except Exception:
+        pass
     from evenage.core.config import load_agents
 
     try:
@@ -81,7 +98,11 @@ def run_local(agent: str, input_json: str):
             env = EvenAgeConfig()
             a = AgentCls(cfg, env)
         except Exception as e:
-            raise click.ClickException(f"Agent not found or cannot be constructed: {e}")
+            hint = (
+                "Make sure you're running this command from your project root where the 'agents/' folder exists, "
+                "and that 'agents/__init__.py' is present."
+            )
+            raise click.ClickException(f"Agent not found or cannot be constructed: {e}\n{hint}")
 
     result = asyncio.run(a.handle(payload))
     click.echo(json.dumps(result, ensure_ascii=False))
