@@ -8,45 +8,15 @@ resolve agents dynamically from the 'agents' package if present.
 from __future__ import annotations
 
 import importlib
+import inspect
 from typing import Dict, Any
-import os
-
-from .tracing import TraceLogger, NoopTracer
-from .factory import BackendFactory
-
-
-def get_bus():
-    # Build bus via BackendFactory honoring runtime config
-    try:
-        cfg = load_runtime_config()
-    except Exception:
-        from .config import EvenAgeConfig
-        cfg = EvenAgeConfig()
-    return BackendFactory(cfg).create_queue_backend()
-
-
-def get_storage():
-    # Return configured storage backend (MinIO or in-memory)
-    try:
-        cfg = load_runtime_config()
-    except Exception:
-        from .config import EvenAgeConfig
-        cfg = EvenAgeConfig()
-    return BackendFactory(cfg).create_storage_backend()
-
-
-def get_tracer():
-    db_url = os.environ.get("DATABASE_URL")
-    if db_url:
-        return TraceLogger(db_url)
-    return NoopTracer()
-
 
 def load_agents() -> Dict[str, Any]:
-    """Load agent classes dynamically from 'agents.<name>.handler'.
+    """Load agents dynamically from 'agents.<name>.handler'.
 
-    Expects each handler to expose a class named <Name>Agent with a default constructor.
-    If absent, skips that agent.
+    Supports two patterns:
+    1) @actor-decorated classes named <Name>Agent (instantiated without args)
+    2) Module-level Agent instances (any variable bound to evenage.core.agent_runtime.Agent)
     """
     discovered: Dict[str, Any] = {}
     try:
@@ -57,9 +27,21 @@ def load_agents() -> Dict[str, Any]:
             name = m.name
             try:
                 mod = importlib.import_module(f"agents.{name}.handler")
-                cls_name = f"{name.capitalize()}Agent"
-                AgentCls = getattr(mod, cls_name)
-                discovered[name] = AgentCls()  # type: ignore[call-arg]
+
+                # Prefer class pattern: <Name>Agent
+                # We intentionally do NOT instantiate here to avoid needing configs.
+                # run-local has a fallback path that constructs the class with AgentConfig/EvenAgeConfig.
+                # So we skip adding classes in this discovery step.
+                # cls_name = f"{name.capitalize()}Agent"
+                # AgentCls = getattr(mod, cls_name, None)
+                # if inspect.isclass(AgentCls):
+                #     pass
+
+                # Instance pattern: find any Agent instance in module globals
+                for var_name, obj in vars(mod).items():
+                    if not inspect.isclass(obj) and callable(getattr(obj, "handle", None)):
+                        discovered[name] = obj
+                        break
             except Exception:
                 continue
     except Exception:
@@ -115,8 +97,7 @@ class EvenAgeConfig(BaseSettings):
     # Kafka (optional)
     kafka_bootstrap: str | None = Field(default=None, description="Kafka bootstrap servers (host:port)")
 
-    # Storage selection and MinIO/S3 settings
-    storage_backend: str = Field(default="minio", description="Storage backend: minio | local")
+    # MinIO/S3 Storage (optional, for large artifacts)
     minio_endpoint: str = Field(default="localhost:9000", description="MinIO endpoint")
     minio_access_key: str = Field(default="minioadmin", description="MinIO access key")
     minio_secret_key: str = Field(
@@ -281,21 +262,30 @@ class BackendFactory:
 
     def create_queue_backend(self) -> QueueBackend:
         """Create message queue backend based on config."""
-        if self.config.queue_backend == "redis":
-            from .backends.queue import RedisBus
+        import os as _os
+        # Respect explicit env override first
+        backend = _os.environ.get("QUEUE_BACKEND", self.config.queue_backend)
+        # Smart default: if user didn't explicitly opt into Redis (no env for
+        # QUEUE_BACKEND and no REDIS_URL), then default to in-memory for a
+        # frictionless local run.
+        if backend == "redis" and ("QUEUE_BACKEND" not in _os.environ) and ("REDIS_URL" not in _os.environ):
+            backend = "memory"
+
+        if backend == "redis":
+            from .message_bus import RedisBus
             bus = RedisBus(self.config.redis_url)
-        elif self.config.queue_backend == "memory":
-            from .backends.queue import MemoryBus
+        elif backend == "memory":
+            from .message_bus import MemoryBus
             if BackendFactory._memory_bus_singleton is None:
                 BackendFactory._memory_bus_singleton = MemoryBus()
             bus = BackendFactory._memory_bus_singleton
-        elif self.config.queue_backend == "kafka":
-            from .backends.queue import KafkaBus
+        elif backend == "kafka":
+            from .message_bus import KafkaBus
             if not self.config.kafka_bootstrap:
                 raise ValueError("kafka_bootstrap is required for kafka queue_backend")
             bus = KafkaBus(self.config.kafka_bootstrap)
         else:
-            raise ValueError(f"Unknown queue_backend: {self.config.queue_backend}")
+            raise ValueError(f"Unknown queue_backend: {backend}")
 
         # Optionally enable large-response offload to storage
         try:
@@ -312,18 +302,11 @@ class BackendFactory:
 
     def create_database_backend(self) -> DatabaseBackend:
         """Create database backend based on config."""
-        from .backends.database import DatabaseService
-        return DatabaseService(self.config.database_url)
-
-    def create_vector_backend(self) -> VectorBackend:
-        """Create vector store backend based on config."""
-        if self.config.vector_backend == "local":
-            from .backends.vector import LocalVectorStore
-            return LocalVectorStore()
-        if self.config.vector_backend == "pgvector":
-            from .backends.vector import PostgresVectorStore
-            return PostgresVectorStore(self.config.database_url)
-        raise ValueError(f"Unknown vector_backend: {self.config.vector_backend}")
+        from .database import DatabaseService
+        import os as _os
+        # Prefer env override if present, then config, else SQLite
+        db_url = _os.environ.get("DATABASE_URL") or self.config.database_url or "sqlite:///evenage.db"
+        return DatabaseService(db_url)
 
     def create_llm_backend(self) -> LLMBackend:
         """Create LLM backend based on config."""
@@ -363,8 +346,8 @@ class BackendFactory:
 
     def create_storage_backend(self):
         """Create storage backend for artifacts (MinIO/S3)."""
-        if self.config.storage_backend == "minio" and self.config.minio_endpoint:
-            from .backends.storage import MinIOStorage
+        if self.config.minio_endpoint:
+            from .storage import MinIOStorage
             return MinIOStorage(
                 endpoint=self.config.minio_endpoint,
                 access_key=self.config.minio_access_key,
@@ -372,83 +355,10 @@ class BackendFactory:
                 secure=self.config.minio_secure
             )
         # Fall back to in-memory storage if no MinIO configured
-        from .backends.storage import InMemoryStorage
+        from .storage import InMemoryStorage
         return InMemoryStorage()
 
 
-# --- Runtime config loader (JSON-driven) ---
-
-def _find_project_root(start: Path | None = None) -> Path | None:
-    """Locate project root by looking for evenage.yml or .evenage/ directory."""
-    current = start or Path.cwd()
-    for directory in [current, *current.parents]:
-        if (directory / "evenage.yml").exists() or (directory / ".evenage").exists():
-            return directory
-    return None
-
-
-def load_runtime_config() -> EvenAgeConfig:
-    """Load EvenAgeConfig, honoring .evenage/config.json when present.
-
-    Rules:
-    - If .evenage/config.json exists, map its fields to EvenAgeConfig overrides
-    - If enable_scaling is false (or absent), default to local lightweight mode:
-        queue_backend=memory, db_backend=sqlite, database_url=sqlite:///./evenage.db, storage_backend=local
-    - If enable_scaling is true, use selected backends with sensible defaults if URLs missing
-    - Environment variables (via BaseSettings) still apply as base; JSON overrides take precedence
-    """
-    base = EvenAgeConfig()  # load from env/.env
-
-    root = _find_project_root()
-    if not root:
-        return base
-
-    json_path = root / ".evenage" / "config.json"
-    if not json_path.exists():
-        return base
-
-    try:
-        import json
-        data = json.loads(json_path.read_text(encoding="utf-8"))
-    except Exception:
-        return base
-
-    enable_scaling = bool(data.get("enable_scaling", False))
-    queue_backend = data.get("queue_backend") or ("redis" if enable_scaling else "memory")
-    db_backend = data.get("db_backend") or ("postgres" if enable_scaling else "sqlite")
-    storage_backend = data.get("storage_backend") or ("minio" if enable_scaling else "local")
-
-    overrides: dict[str, Any] = {
-        "queue_backend": queue_backend,
-        "db_backend": db_backend,
-        "storage_backend": storage_backend,
-    }
-
-    # URLs / endpoints
-    if db_backend == "sqlite":
-        overrides["database_url"] = "sqlite:///./evenage.db"
-    elif db_backend == "postgres" and not getattr(base, "database_url", None):
-        overrides["database_url"] = "postgresql://evenage:evenage@localhost:5432/evenage"
-
-    if queue_backend == "redis" and not getattr(base, "redis_url", None):
-        overrides["redis_url"] = "redis://localhost:6379"
-
-    if storage_backend == "minio":
-        # Use defaults unless already set via env
-        if not getattr(base, "minio_endpoint", None):
-            overrides["minio_endpoint"] = "localhost:9000"
-        overrides.setdefault("minio_access_key", base.minio_access_key)
-        overrides.setdefault("minio_secret_key", base.minio_secret_key)
-        overrides.setdefault("minio_secure", base.minio_secure)
-    else:
-        # Local storage: disable minio usage
-        overrides["minio_endpoint"] = ""
-
-    # Vector/LLM/cache remain as in env unless we choose to derive them later
-
-    return EvenAgeConfig(**{**base.model_dump(), **overrides})
-
-
 
 class ProjectConfig(BaseModel):
     """
@@ -481,7 +391,7 @@ class AgentConfig(BaseModel):
     role: str
     goal: str
     backstory: str | None = None
-    max_iterations: int = Field(default=15)
+    max_iterations: int = Field(default=5)  # Reduced from 7 to 5 - forced finish at 4 successful tools
     allow_delegation: bool = Field(default=True)
     verbose: bool = Field(default=False)
 
@@ -499,80 +409,3 @@ class PipelineConfig(BaseModel):
     name: str
     description: str | None = None
     stages: list[PipelineStage]
-
-
-def load_project_config(path: Path | str = "evenage.yml") -> ProjectConfig:
-    """Load project configuration from YAML file."""
-    path = Path(path)
-    if not path.exists():
-        raise FileNotFoundError(f"Configuration file not found: {path}")
-
-    with open(path) as f:
-        data = yaml.safe_load(f)
-
-    return ProjectConfig(**data.get("project", {}))
-
-
-def save_project_config(config: ProjectConfig, path: Path | str = "evenage.yml") -> None:
-    """Save project configuration to YAML file."""
-    path = Path(path)
-    data = {"project": config.model_dump(exclude_none=True)}
-
-    with open(path, "w") as f:
-        yaml.dump(data, f, default_flow_style=False, sort_keys=False)
-
-
-def load_pipeline_config(path: Path | str) -> PipelineConfig:
-    """Load pipeline configuration from YAML file."""
-    path = Path(path)
-    if not path.exists():
-        raise FileNotFoundError(f"Pipeline configuration not found: {path}")
-
-    with open(path) as f:
-        data = yaml.safe_load(f)
-
-    return PipelineConfig(**data)
-
-
-# --- Code-first infra convenience ---
-
-
-def connect_infrastructure(config: EvenAgeConfig):
-    """
-    Explicitly connect all core infrastructure from a config instance.
-
-    Returns a lightweight object with attributes:
-    bus, database, vector, llm, storage, cache
-    """
-    from evenage.infra import Infra
-
-    factory = BackendFactory(config)
-
-    # Core backends
-    bus = factory.create_queue_backend()
-    database = factory.create_database_backend()
-    storage = factory.create_storage_backend()
-
-    # Optional backends
-    try:
-        vector = factory.create_vector_backend()
-    except Exception:
-        vector = None
-
-    try:
-        llm = factory.create_llm_backend()
-    except Exception:
-        llm = None
-
-    cache = factory.create_cache_backend()
-
-    return Infra(
-        bus=bus,
-        database=database,
-        vector=vector,
-        llm=llm,
-        storage=storage,
-        cache=cache,
-    )
-
-
