@@ -23,8 +23,12 @@ class OpenAILLM:
     """OpenAI LLM backend."""
 
     def __init__(self, api_key: str | None, model: str | None = None, base_url: str | None = None):
-        self.api_key = api_key
-        self.default_model = model or "gpt-4"
+        import os
+        self.api_key = api_key or os.getenv("OPENAI_API_KEY")
+        # Support per-agent model config via env
+        self.default_model = (
+            model or os.getenv("AGENT_MODEL") or os.getenv("OPENAI_MODEL") or "gpt-4"
+        )
         self.base_url = base_url
         self._client = None
 
@@ -69,7 +73,8 @@ class AnthropicLLM:
     """Anthropic LLM backend."""
 
     def __init__(self, api_key: str | None, model: str | None = None):
-        self.api_key = api_key
+        import os
+        self.api_key = api_key or os.getenv("ANTHROPIC_API_KEY")
         self.default_model = model or "claude-3-sonnet-20240229"
         self._client = None
 
@@ -99,7 +104,8 @@ class GeminiLLM:
     """Google Gemini LLM backend."""
 
     def __init__(self, api_key: str | None, model: str | None = None):
-        self.api_key = api_key
+        import os
+        self.api_key = api_key or os.getenv("GEMINI_API_KEY")
         self.default_model = model or "gemini-2.5-flash"
         self._model = None
 
