@@ -96,6 +96,7 @@ class RedisBus:
     def __init__(self, redis_url: str):
         self.redis_url = redis_url
         self._client = None
+        self._cancel_prefix = "evenage:cancel:"
 
     async def _get_client(self) -> Any:
         """Lazy connection to Redis."""
@@ -162,7 +163,7 @@ class RedisBus:
             threshold_kb = getattr(self, "_storage_threshold_kb", None)
 
             payload_bytes = json.dumps(response).encode("utf-8")
-            if storage and threshold_kb and len(payload_bytes) > threshold_kb * 1024:
+            if storage and threshold_kb is not None and len(payload_bytes) > threshold_kb * 1024:
                 # Build a key with date prefix for grouping
                 date_prefix = datetime.utcnow().strftime("%Y/%m/%d")
                 key = f"responses/{date_prefix}/{task_id}.json"
@@ -200,18 +201,30 @@ class RedisBus:
 
     async def consume_tasks(self, agent_name: str, block_ms: int, count: int) -> list[dict]:
         """
-        Consume tasks from agent's queue.
+        Consume tasks from agent's queue using consumer groups.
         
+        Ensures each task is delivered to only ONE worker in a multi-worker setup.
         Blocks up to block_ms milliseconds waiting for tasks.
         Returns up to count tasks.
         """
         client = await self._get_client()
         stream_name = f"evenage:tasks:{agent_name}"
+        group_name = f"{agent_name}_workers"
+        consumer_name = f"worker_{uuid.uuid4().hex[:8]}"  # Unique consumer ID per call
 
-        # Read from stream
+        # Ensure consumer group exists (idempotent operation)
         try:
-            result = await client.xread(
-                {stream_name: "$"},  # Read new messages
+            await client.xgroup_create(stream_name, group_name, id="0", mkstream=True)
+        except Exception:
+            # Group already exists, ignore error
+            pass
+
+        # Read from stream using consumer group (guarantees single delivery)
+        try:
+            result = await client.xreadgroup(
+                groupname=group_name,
+                consumername=consumer_name,
+                streams={stream_name: ">"},  # ">" means undelivered messages
                 count=count,
                 block=block_ms
             )
@@ -225,7 +238,10 @@ class RedisBus:
                     data = json.loads(msg_data["data"])
                     tasks.append(data)
 
-                    # ACK by deleting (simple approach)
+                    # ACK the message so it's not re-delivered
+                    await client.xack(stream_name, group_name, msg_id)
+                    
+                    # Optional: Clean up acknowledged messages to prevent stream growth
                     await client.xdel(stream_name, msg_id)
 
             return tasks
@@ -278,6 +294,19 @@ class RedisBus:
 
         return agents
 
+    async def list_agents(self) -> list[dict]:
+        """Return a list of agent summaries for planning/delegation."""
+        registry = await self.get_registered_agents()
+        agents_list: list[dict] = []
+        for name, meta in registry.items():
+            agents_list.append({
+                "name": name,
+                "role": meta.get("role"),
+                "goal": meta.get("goal"),
+                "status": meta.get("status", "unknown"),
+            })
+        return agents_list
+
     async def get_queue_depth(self, agent_name: str) -> int:
         """Get number of pending tasks for an agent."""
         client = await self._get_client()
@@ -297,6 +326,26 @@ class RedisBus:
         except Exception:
             return False
 
+    async def cancel_job(self, job_id: str) -> bool:
+        """Mark a job as canceled with a TTL flag in Redis."""
+        client = await self._get_client()
+        key = f"{self._cancel_prefix}{job_id}"
+        try:
+            await client.setex(key, 3600, "1")
+            return True
+        except Exception:
+            return False
+
+    async def is_canceled(self, job_id: str) -> bool:
+        """Check whether a cancel flag is present for a job."""
+        client = await self._get_client()
+        key = f"{self._cancel_prefix}{job_id}"
+        try:
+            val = await client.get(key)
+            return bool(val)
+        except Exception:
+            return False
+
 
 class MemoryBus:
     """
@@ -310,6 +359,7 @@ class MemoryBus:
         self._tasks: dict[str, list[dict]] = {}
         self._responses: dict[str, dict] = {}
         self._waiters: dict[str, list[asyncio.Future]] = {}
+        self._canceled: set[str] = set()
 
     async def register_agent(self, name: str, metadata: dict) -> bool:
         """Register an agent with metadata."""
@@ -339,7 +389,7 @@ class MemoryBus:
             bucket = getattr(self, "_storage_bucket", None) or "evenage"
             threshold_kb = getattr(self, "_storage_threshold_kb", None)
             payload_bytes = json.dumps(response).encode("utf-8")
-            if storage and threshold_kb and len(payload_bytes) > threshold_kb * 1024:
+            if storage and threshold_kb is not None and len(payload_bytes) > threshold_kb * 1024:
                 date_prefix = datetime.utcnow().strftime("%Y/%m/%d")
                 key = f"responses/{date_prefix}/{task_id}.json"
                 metadata = {"content-type": "application/json"}
@@ -392,12 +442,32 @@ class MemoryBus:
     async def get_registered_agents(self) -> dict[str, dict]:
         return dict(self._agents)
 
+    async def list_agents(self) -> list[dict]:
+        """Return a list of agent summaries for planning/delegation."""
+        registry = await self.get_registered_agents()
+        return [
+            {
+                "name": name,
+                "role": meta.get("role"),
+                "goal": meta.get("goal"),
+                "status": meta.get("status", "unknown"),
+            }
+            for name, meta in registry.items()
+        ]
+
     async def get_queue_depth(self, agent_name: str) -> int:
         return len(self._tasks.get(agent_name, []))
 
     async def health_check(self) -> bool:
         return True
 
+    async def cancel_job(self, job_id: str) -> bool:
+        self._canceled.add(job_id)
+        return True
+
+    async def is_canceled(self, job_id: str) -> bool:
+        return job_id in self._canceled
+
 
 class KafkaBus:
     """
@@ -415,6 +485,7 @@ class KafkaBus:
         self._producer = None
         self._agents: dict[str, dict] = {}
         self._waiters: dict[str, list[asyncio.Future]] = {}
+        self._canceled: set[str] = set()
 
     async def _get_producer(self) -> Any:
         if self._producer is None:
@@ -443,7 +514,7 @@ class KafkaBus:
             bucket = getattr(self, "_storage_bucket", None) or "evenage"
             threshold_kb = getattr(self, "_storage_threshold_kb", None)
             payload_bytes = json.dumps(response).encode("utf-8")
-            if storage and threshold_kb and len(payload_bytes) > threshold_kb * 1024:
+            if storage and threshold_kb is not None and len(payload_bytes) > threshold_kb * 1024:
                 date_prefix = datetime.utcnow().strftime("%Y/%m/%d")
                 key = f"responses/{date_prefix}/{task_id}.json"
                 metadata = {"content-type": "application/json"}
@@ -518,6 +589,19 @@ class KafkaBus:
     async def get_registered_agents(self) -> dict[str, dict]:
         return dict(self._agents)
 
+    async def list_agents(self) -> list[dict]:
+        """Return a list of agent summaries for planning/delegation."""
+        registry = await self.get_registered_agents()
+        return [
+            {
+                "name": name,
+                "role": meta.get("role"),
+                "goal": meta.get("goal"),
+                "status": meta.get("status", "unknown"),
+            }
+            for name, meta in registry.items()
+        ]
+
     async def get_queue_depth(self, agent_name: str) -> int:
         # Not tracked in this minimal implementation
         return 0
@@ -529,3 +613,10 @@ class KafkaBus:
             return True
         except Exception:
             return False
+
+    async def cancel_job(self, job_id: str) -> bool:
+        self._canceled.add(job_id)
+        return True
+
+    async def is_canceled(self, job_id: str) -> bool:
+        return job_id in self._canceled
