@@ -14,7 +14,7 @@ from contextlib import suppress
 import time
 import uuid
 
-from .agent import Agent
+from .agent_runtime import Agent
 from .config import AgentConfig, BackendFactory, EvenAgeConfig
 
 
@@ -69,32 +69,35 @@ class AgentRunner:
         """
         # Determine agent
         if agent_name:
-            # Load agent class dynamically. Prefer local project agents; fall back to internal test agents only during framework development.
+            # Try flat module style: agents/<name>.py exporting an Agent instance named <name>
             try:
-                agent_mod = importlib.import_module(f"agents.{agent_name}.handler")
-                AgentClass = getattr(agent_mod, f"{agent_name.capitalize()}Agent")
-            except (ModuleNotFoundError, AttributeError) as primary_err:
-                # Optional fallback for EvenAge repo development (not user projects)
+                mod = importlib.import_module(f"agents.{agent_name}")
+                candidate = getattr(mod, agent_name, None)
+                if candidate and hasattr(candidate, "handle"):
+                    agent = candidate  # type: ignore[assignment]
+                else:
+                    raise AttributeError("No module-level agent instance found")
+            except Exception:
+                # Fallback to legacy handler class pattern: agents/<name>/handler.py with <Name>Agent
                 try:
-                    agent_mod = importlib.import_module(f"evenage.tests.agents.{agent_name}.handler")
+                    agent_mod = importlib.import_module(f"agents.{agent_name}.handler")
                     AgentClass = getattr(agent_mod, f"{agent_name.capitalize()}Agent")
-                except Exception:
-                    # Hide internal fallback path from user-facing error to avoid confusion
-                    raise ValueError(
-                        f"Could not load agent '{agent_name}'. "
-                        f"Ensure 'agents/{agent_name}/handler.py' exists and defines '{agent_name.capitalize()}Agent'. "
-                        f"Root cause: {primary_err}"
+                    agent_config = AgentConfig(
+                        name=getattr(AgentClass, 'AGENT_NAME', agent_name),
+                        role=getattr(AgentClass, 'ROLE', 'Agent'),
+                        goal=getattr(AgentClass, 'GOAL', 'Execute tasks')
                     )
-
-            # Get agent config from the class decorator metadata
-            agent_config = AgentConfig(
-                name=getattr(AgentClass, 'AGENT_NAME', agent_name),
-                role=getattr(AgentClass, 'ROLE', 'Agent'),
-                goal=getattr(AgentClass, 'GOAL', 'Execute tasks')
-            )
-
-            agent = AgentClass(agent_config, self.env_config)
-            await agent.connect_bus()
+                    agent = AgentClass(agent_config, self.env_config)
+                except Exception as primary_err:
+                    raise ValueError(
+                        f"Could not load agent '{agent_name}'. Ensure 'agents/{agent_name}.py' defines '{agent_name}' Agent instance "
+                        f"or legacy 'agents/{agent_name}/handler.py' defines '{agent_name.capitalize()}Agent'. Root cause: {primary_err}"
+                    )
+            # Ensure bus registration
+            try:
+                await agent.connect_bus()
+            except Exception:
+                pass
         elif self.agent:
             agent = self.agent
         else:
@@ -499,3 +502,59 @@ async def run_agent(
     """
     runner = AgentRunner(env_config=env_config)
     return await runner.run(inputs, agent_name=agent_name)
+
+
+class WorkerRunner:
+    """
+    Lightweight worker runner for a single agent instance.
+
+    Consumes tasks from the message bus for the agent's name and publishes results.
+    """
+
+    def __init__(
+        self,
+        agent: Agent,
+        database_url: str | None = None,
+        redis_url: str | None = None,
+        minio_endpoint: str | None = None,
+        minio_access_key: str | None = None,
+        minio_secret_key: str | None = None,
+        minio_secure: bool | None = None,
+    ) -> None:
+        # Build env config from provided values (fallback to defaults)
+        self.env_config = EvenAgeConfig(
+            database_url=database_url or EvenAgeConfig().database_url,
+            redis_url=redis_url or EvenAgeConfig().redis_url,
+            minio_endpoint=minio_endpoint or EvenAgeConfig().minio_endpoint,
+            minio_access_key=minio_access_key or EvenAgeConfig().minio_access_key,
+            minio_secret_key=minio_secret_key or EvenAgeConfig().minio_secret_key,
+            minio_secure=bool(minio_secure) if minio_secure is not None else EvenAgeConfig().minio_secure,
+        )
+        self.factory = BackendFactory(self.env_config)
+        self.agent = agent
+
+    async def start(self) -> None:
+        """Start processing tasks indefinitely for the agent's queue."""
+        # Ensure agent is connected/registered
+        try:
+            await self.agent.connect_bus()
+        except Exception:
+            pass
+
+        bus = self.agent.bus or self.factory.create_queue_backend()
+        agent_name = self.agent.config.name
+
+        while True:
+            tasks = await bus.consume_tasks(agent_name, block_ms=2000, count=5)
+            if not tasks:
+                continue
+            for message in tasks:
+                task_id = message.get("task_id")
+                payload = message.get("payload", {})
+                try:
+                    result = await self.agent.handle(payload)
+                    if task_id:
+                        await bus.publish_response(task_id, result)
+                except Exception as e:
+                    if task_id:
+                        await bus.publish_response(task_id, {"status": "error", "error": str(e)})
