@@ -1,60 +1,11 @@
 """
-Storage backends for artifact management (re-exports from core.backends.storage).
-
-Legacy ArtifactStorage helper for backward compatibility.
+Artifact storage abstraction with local and MinIO backends.
 """
 
 from __future__ import annotations
 
 import io
-import json
-import os
-import uuid
-from typing import Any
 
-# Re-export unified storage backends
-from .backends.storage import InMemoryStorage, MinIOStorage
-
-
-class ArtifactStorage:
-    """
-    Legacy artifact storage helper (v3 compatibility).
-    
-    Wraps the new backends for backward compatibility.
-    Prefer using MinIOStorage or InMemoryStorage directly from core.backends.storage.
-    """
-    def __init__(self, backend: str = "local", **kwargs):
-        self.backend = backend
-        if backend == "minio":
-            from minio import Minio  # type: ignore
-            self.client = Minio(
-                kwargs["endpoint"],
-                access_key=kwargs.get("key"),
-                secret_key=kwargs.get("secret"),
-                secure=bool(kwargs.get("secure", False)),
-            )
-            self.bucket = kwargs.get("bucket", "evenage-artifacts")
-            if not self.client.bucket_exists(self.bucket):
-                self.client.make_bucket(self.bucket)
-        else:
-            self.path = kwargs.get("path", "./artifacts")
-            os.makedirs(self.path, exist_ok=True)
-
-    def put(self, data: Any) -> str:
-        key = f"{uuid.uuid4()}.json"
-        if self.backend == "local":
-            target = os.path.join(self.path, key)
-            with open(target, "w", encoding="utf-8") as f:
-                json.dump(data, f)
-            return f"file://{os.path.abspath(target)}"
-        else:
-            body = json.dumps(data).encode()
-            self.client.put_object(self.bucket, key, io.BytesIO(body), len(body))
-            return f"s3://{self.bucket}/{key}"
-
-
-# Keep the rest of the async storage implementations below (MinIOStorage, InMemoryStorage)
-# Note: These are duplicated from backends; the canonical versions are in core.backends.storage
 """
 Storage backends for artifact management.
 
@@ -141,12 +92,28 @@ class MinIOStorage:
 
         def _put():
             client = self._get_client()
+            # MinIO signing can fail if content-type is passed inside metadata,
+            # so map common keys to the dedicated content_type parameter and
+            # pass only non-reserved metadata keys.
+            content_type = None
+            meta = None
+            if metadata:
+                # Extract content type from common variations
+                content_type = (
+                    metadata.get("content-type")
+                    or metadata.get("Content-Type")
+                    or metadata.get("content_type")
+                )
+                # Filter out content-type keys from metadata dict
+                meta = {k: v for k, v in metadata.items() if k.lower() not in ("content-type", "content_type")}
+
             client.put_object(
                 bucket,
                 key,
                 io.BytesIO(data),
                 length=len(data),
-                metadata=metadata
+                content_type=content_type,
+                metadata=meta,
             )
             return True
 
